/** \mainpage Driver Overview
  *
  * \section section_drv_info Driver Information
  * This Sensor Controller Interface driver has been generated by the Texas Instruments Sensor Controller
  * Studio tool:
  * - <b>Project name</b>:     LC Flow Meter for TID010050
  * - <b>Project file</b>:     C:/Users/a0224194/workspace_v7/TIDA010050_0211/TIDA_010050_SW/sce/LC_sensor.scp
  * - <b>Code prefix</b>:      -
  * - <b>Operating system</b>: TI-RTOS
  * - <b>Tool version</b>:     2.4.0.793
  * - <b>Tool patches</b>:     None
  * - <b>Target chip</b>:      CC1312R1F3, package QFN48 7x7 RGZ, revision E (2.1)
  * - <b>Created</b>:          2019-03-01 16:10:06.866
  * - <b>Computer</b>:         CNA0224194
  * - <b>User</b>:             a0224194
  *
  * No user-provided resource definitions were used to generate this driver.
  *
  * No user-provided procedure definitions were used to generate this driver.
  *
  * Do not edit the generated source code files other than temporarily for debug purposes. Any
  * modifications will be overwritten by the Sensor Controller Studio when generating new output.
  *
  * \section section_drv_modules Driver Modules
  * The driver is divided into three modules:
  * - \ref module_scif_generic_interface, providing the API for:
  *     - Initializing and uninitializing the driver
  *     - Task control (for starting, stopping and executing Sensor Controller tasks)
  *     - Task data exchange (for producing input data to and consume output data from Sensor Controller
  *       tasks)
  * - \ref module_scif_driver_setup, containing:
  *     - The AUX RAM image (Sensor Controller code and data)
  *     - I/O mapping information
  *     - Task data structure information
  *     - Driver setup data, to be used in the driver initialization
  *     - Project-specific functionality
  * - \ref module_scif_osal, for flexible OS support:
  *     - Interfaces with the selected operating system
  *
  * It is possible to use output from multiple Sensor Controller Studio projects in one application. Only
  * one driver setup may be active at a time, but it is possible to switch between these setups. When
  * using this option, there is one instance of the \ref module_scif_generic_interface and
  * \ref module_scif_osal modules, and multiple instances of the \ref module_scif_driver_setup module.
  * This requires that:
  * - The outputs must be generated using the same version of Sensor Controller Studio
  * - The outputs must use the same operating system
  * - The outputs must use different source code prefixes (inserted into all globals of the
  *   \ref module_scif_driver_setup)
  *
  *
  * \section section_project_info Project Description
  * The Sensor Controller samples the two LC sensors, which are located under a rotating disc. See the
  * task description for details.
  *
  *
  * \subsection section_io_mapping I/O Mapping
  * Task I/O functions are mapped to the following pins:
  * - LC Flow Meter:
  *     - <b>AXD: Flow meter output 1</b>: DIO26
  *     - <b>AXD: Flow meter output 2</b>: DIO28
  *     - <b>AXD: force inductor1 teiminal to GND </b>: DIO25
  *     - <b>AXD: force inductor2 teiminal to GND </b>: DIO29
  *     - <b>XS: Flow meter power control</b>: DIO12
  *     - <b>O: Flow meter trigger 2</b>: DIO17
  *     - <b>O: Flow meter trigger 1</b>: DIO16
  *
  *
  * \section section_task_info Task Description(s)
  * This driver supports the following task(s):
  *
  *
  * \subsection section_task_desc_lc_flow_meter LC Flow Meter
  * Samples the LC flow meter with TIDA-010050, by using the Pulse Counter, COMPA and Reference DAC
  * peripherals.
  * 
  * There are two separate flow meter LC sensors that are placed 90 degrees relative to each other under
  * the rotating disc, which is half-metal coated / half non-metal. When the disc rotates, the
  * measurements produce a 2-bit gray-code, where each code corresponds one quadrant of a full rotation.
  * This is then used to count rotations.
  * 
  * Each LC sensor consists of an inductor and a capacitor connected in parallel. To start a measurement,
  * the Sensor controller uses GPIO to trigger external circuitry, which in turn causes the LC sensor to
  * oscillate. The oscillation dampening depends on whether or not the metal part of the disc is over the
  * inductor. The Pulse Counter is used to count the number of oscillations on the COMPA input, before
  * the amplitude has reduced to the Reference DAC level.
  * 
  * For simplicity, the Sensor Controller task performs automatic calibration. Two calibrations are
  * performed:
  * - The initialization code finds the Reference DAC value for each channel.
  *     - The DAC value used in the execution code = "DAC value that corresponds to the bias voltage" +
  * REFDAC_OFFSET
  *     - The Reference DAC provides reference for COMPA during measurements.
  * - The execution code finds the threshold pulse counts for each channel.
  *     - The calibration finds the minimum and maximum pulse counts during the two first rotations, and
  * sets the threshold to the middle value.
  *     - The required difference between minimum and maximum pulse count is configured by
  * CAL_MIN_MAX_DIFF.
  *     - The thresholds are used to generate a 2-bit gray-coded rotation state.
  * 
  * After calibration the Sensor Controller counts rotations, and detects errors:
  * - The rotation count increases by 1 for each clockwise rotation.
  * - The rotation count decreases by 1 for each counter clockwise rotation.
  * - The error count increases by 1 if both bits in the gray code change from one measurement to the
  * next.
  * 
  * LAUNCHPAD SETUP:
  * - Remove TDO and TDI jumpers
  * 
  * TIDA-010050 SETUP:
  * - Mount the jumper: J3
  * 
  * 
  * MECHANICAL SETUP:
  * - Use a disc where one half is made from (or plated with) steel. Do not use copper or aluminium.
  * - Rotate the disc over the centre hole, above the inductors. Ensure that the rotation axle is stable,
  * and that the disc does not vibrate.
  * 
  * See the header in the application source file ("main_tirtos.c") for further details and instructions.
  * This file is located in the source code output directory.
  *
  */




/** \addtogroup module_scif_driver_setup Driver Setup
  *
  * \section section_driver_setup_overview Overview
  *
  * This driver setup instance has been generated for:
  * - <b>Project name</b>:     LC Flow Meter for TID010050
  * - <b>Code prefix</b>:      -
  *
  * The driver setup module contains the generated output from the Sensor Controller Studio project:
  * - Location of task control and scheduling data structures in AUX RAM
  * - The AUX RAM image, and the size the image
  * - Task data structure information (location, size and buffer count)
  * - I/O pin mapping translation table
  * - Task resource initialization and uninitialization functions
  * - Hooks for run-time logging
  *
  * @{
  */
#ifndef SCIF_H
#define SCIF_H

#include <stdint.h>
#include <stdbool.h>
#include "scif_framework.h"
#include "scif_osal_tirtos.h"


/// Target chip name
#define SCIF_TARGET_CHIP_NAME_CC1312R1F3
/// Target chip package
#define SCIF_TARGET_CHIP_PACKAGE_QFN48_7X7_RGZ

/// Number of tasks implemented by this driver
#define SCIF_TASK_COUNT 1

/// LC Flow Meter: Task ID
#define SCIF_LC_FLOW_METER_TASK_ID 0


/// LC Flow Meter: Least required difference between minimum and maximum pulse count
#define SCIF_LC_FLOW_METER_CAL_MIN_MAX_DIFF 3
/// LC Flow Meter: Calibration state: Done (calibration completed)
#define SCIF_LC_FLOW_METER_CAL_STATE_DONE 0
/// LC Flow Meter: Calibration state: Initial (start of calibration)
#define SCIF_LC_FLOW_METER_CAL_STATE_INIT 4
/// LC Flow Meter: FLOW 1 channel index
#define SCIF_LC_FLOW_METER_CHANNEL_1 0
/// LC Flow Meter: FLOW 2 channel index
#define SCIF_LC_FLOW_METER_CHANNEL_2 1
/// LC Flow Meter: Number of channels to be measured
#define SCIF_LC_FLOW_METER_CHANNEL_COUNT 2
/// LC Flow Meter: Offset added to Reference DAC calibration result for each channel
#define SCIF_LC_FLOW_METER_REFDAC_OFFSET 11
/// LC Flow Meter: Number of rotation states
#define SCIF_LC_FLOW_METER_ROTATION_STATE_COUNT 4
/// LC Flow Meter I/O mapping: Flow meter output 1
#define SCIF_LC_FLOW_METER_DIO_AXD_FLOW_OUTPUT_1 26
/// LC Flow Meter I/O mapping: Flow meter output 2
#define SCIF_LC_FLOW_METER_DIO_AXD_FLOW_OUTPUT_2 28
/// LC Flow Meter I/O mapping: force inductor1 teiminal to GND 
#define SCIF_LC_FLOW_METER_DIO_AXD_FORCE_LOW_1 25
/// LC Flow Meter I/O mapping: force inductor2 teiminal to GND 
#define SCIF_LC_FLOW_METER_DIO_AXD_FORCE_LOW_2 29
/// LC Flow Meter I/O mapping: Flow meter power control
#define SCIF_LC_FLOW_METER_DIO_XS_FLOW_POWER 12
/// LC Flow Meter I/O mapping: Flow meter trigger 2
#define SCIF_LC_FLOW_METER_DIO_O_FLOW_TRIGGER_2 17
/// LC Flow Meter I/O mapping: Flow meter trigger 1
#define SCIF_LC_FLOW_METER_DIO_O_FLOW_TRIGGER_1 16


// All shared data structures in AUX RAM need to be packed
#pragma pack(push, 2)


/// LC Flow Meter: Task configuration structure
typedef struct {
    uint16_t execInterval; ///< Task execution interval [250 us]
} SCIF_LC_FLOW_METER_CFG_T;


/// LC Flow Meter: Task output data structure
typedef struct {
    uint16_t diff[2];            ///< 
    uint16_t errorCount;         ///< Number of erroneous measurements (noise or too fast rotation)
    uint16_t pCalState[2];       ///< Calibration state (CAL_STATE_*) for each channel
    int16_t  pMeasPulseCount[2]; ///< Measured pulse count for each channel
    int16_t  rotationCount;      ///< Number of clockwise rotations
    uint16_t threshold[2];       ///< 
} SCIF_LC_FLOW_METER_OUTPUT_T;


/// LC Flow Meter: Task state structure
typedef struct {
    uint16_t lastRotationState; ///< Last rotation state (bit N maps to channel N)
    uint16_t pMaxPulseCount[2]; ///< Maximum pulse count measured
    uint16_t pMinPulseCount[2]; ///< Minimum pulse count measured
    uint16_t pRefdacOutput[2];  ///< Reference DAC output value for each channel
    uint16_t pRotationFsm[4];   ///< Rotation state machine (word = last state, nibble = new state, nibble value: 0 = no change, 1 = decr, 2 = incr, 4 = error)
} SCIF_LC_FLOW_METER_STATE_T;


/// Sensor Controller task data (configuration, input buffer(s), output buffer(s) and internal state)
typedef struct {
    struct {
        SCIF_LC_FLOW_METER_CFG_T cfg;
        SCIF_LC_FLOW_METER_OUTPUT_T output;
        SCIF_LC_FLOW_METER_STATE_T state;
    } lcFlowMeter;
} SCIF_TASK_DATA_T;

/// Sensor Controller task generic control (located in AUX RAM)
#define scifTaskData    (*((volatile SCIF_TASK_DATA_T*) 0x400E0170))


// Initialized internal driver data, to be used in the call to \ref scifInit()
extern const SCIF_DATA_T scifDriverSetup;


// Restore previous struct packing setting
#pragma pack(pop)


// AUX I/O re-initialization functions
void scifReinitTaskIo(uint32_t bvTaskIds);


// No task-specific API available


#endif
//@}


// Generated by CNA0224194 at 2019-03-01 16:10:06.866
